==> terraform-0.2.11.tgz: terraform-0.2.11/src/GuiDialogAbout.cc <==
/* Terraform - (C) 1997-1998 Robert Gasch (Robert_Gasch@peoplesoft.com)
 *  - www.peoplesoft.com/peoplepages/g/robert_gasch/terraform/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#include <stdio.h>
#include "terraform.h"
#include "GuiDialogAbout.h"				// include gtk, gtk--
#include "GlobalSanityCheck.h"
#include "GlobalTrace.h"
#include "MathRandom.h"



/*
 * Constructor: init everything 
 */
GuiDialogAbout::GuiDialogAbout (char *winTitle, char *filename, 
				char **msgPtrs, int nMesgs)
		: Gtk_Window (),
		  d_preview (GTK_PREVIEW_COLOR),
#ifdef HAVE_IMLIB
		  d_vBox (FALSE, 0),
		  d_frame (),
	 	  d_vBoxFrame (FALSE, 0)
#else
		  d_vBox (FALSE, 0)
#endif
{
	GlobalTrace::trace (GlobalTrace::TRACE_VERBOSE, "+++ GuiDialogAbout\n");

	SanityCheck::bailout ((!winTitle), "winTitle==NULL", "GuiAboutDialog::GuiAboutDialog");
#ifdef HAVE_IMLIB
	SanityCheck::bailout ((!filename), "filename==NULL", "GuiAboutDialog::GuiAboutDialog");
	SanityCheck::bailout ((!strlen (filename)), "strlen(filename)==0", "GuiAboutDialog::GuiAboutDialog");
#endif

	connect_to_method (button_press_event, this, &handleButtonPressEvent);

	d_winTitle = winTitle;
	d_imageFile = filename;
	d_msgPtrs = msgPtrs;
	d_nMessage = nMesgs;
	d_lblPtrs = NULL;
	this->set_events (GDK_BUTTON_PRESS_MASK | GDK_EXPOSURE_MASK);
}


/*
 * Destructor
 */
GuiDialogAbout::~GuiDialogAbout ()
{
	if (d_lblPtrs)
		{
		for (int i=0; i<d_nMessage; i++)
			delete d_lblPtrs[i];
		delete [] d_lblPtrs;
		}

	GlobalTrace::trace (GlobalTrace::TRACE_VERBOSE, "--- GuiDialogAbout\n");
}


/*
 *  buildDialogWindow: call the proper functions to setup the window
 */
void GuiDialogAbout::buildDialogWindow ()
{
        this->set_title (d_winTitle);
	this->add (d_vBox);
        d_vBox.set_border_width (0);

#ifdef HAVE_IMLIB
	loadLogo ();
	d_vBox.pack_start (d_preview, TRUE, TRUE, 0);
	d_preview.show ();

	d_vBox.pack_start (d_frame, TRUE, TRUE, 0);
	d_frame.show ();
	d_frame.set_shadow_type (GTK_SHADOW_ETCHED_IN);
	d_frame.add (d_vBoxFrame);

	addLabels (&d_vBoxFrame);
	d_vBoxFrame.show ();

	//printf ("%d\n", d_lbl1->height());
	// how do I calculate the proper window height? 
	// d_lbl1->height() returns 1
	this->set_usize (d_image->rgb_width, d_image->rgb_height+15*d_nMessage);
#else
	addLabels (&d_vBox);
	this->set_usize (150, 75);
#endif

        d_vBox.show ();
        this->show ();
}


void GuiDialogAbout::addLabels (Gtk_VBox *vbox)
{
	char	buf[80];

	SanityCheck::bailout ((!vbox), "vbox==NULL", "GuiAboutDialog::addLabels");

	if (!d_msgPtrs)
		return;

	d_lblPtrs = new Gtk_Label*[++d_nMessage];

	sprintf (buf, "Version %d.%d.%d", 
		TF_MAJOR_VERSION, TF_MINOR_VERSION, TF_MICRO_VERSION);
	d_lblPtrs[0] = new Gtk_Label (buf);
	vbox->pack_start (*(d_lblPtrs[0]), FALSE, FALSE, 0);
	d_lblPtrs[0]->show ();

	for (int i=1; i<d_nMessage; i++)
		{
		d_lblPtrs[i] = new Gtk_Label (d_msgPtrs[i-1]);
		vbox->pack_start (*(d_lblPtrs[i]), FALSE, FALSE, 0);
		d_lblPtrs[i]->show ();
		}
}


/*
 *  handleButtonPressEvent: catch a pressed button 
 */
gint GuiDialogAbout::handleButtonPressEvent(GdkEventButton *e)
{
	this->hide ();
	return (0);
}


/*
 *  delete_event_impl: catch the delete event
 */
gint GuiDialogAbout::delete_event_impl (GdkEventAny *)
{
	this->hide ();
	return (0);
}


#ifdef HAVE_IMLIB

/*
 *  load_logo: load the logo from file into preview (and add preview to d_vBox)
 */
int GuiDialogAbout::loadLogo ()
{
	int		w, w3, h;
	guchar 		*pixelrow = NULL;
	MathRandom	*mRand = new MathRandom();

	gdk_imlib_init ();
	d_image = gdk_imlib_load_image (d_imageFile);
	w = d_image->rgb_width;
	h = d_image->rgb_height;

	d_preview.size (w, h);

	w3 = w*3;
	pixelrow = new guchar[w3];
	for (int i=0; i<h; i++)
		{
		memcpy (pixelrow, d_image->rgb_data+w3*i, w3);
		d_preview.draw_row (pixelrow, 0, i, w);
		}

	delete mRand;
	delete [] pixelrow;
	return (0);
}

#endif // HAVE_IMLIB

/*
int GlobalTrace::s_traceLevel = 255;
int main (int argc, char *argv[])
{
	Gtk_Main        gtkMain (&argc, &argv);
	GuiDialogAbout *testDialog;

	testDialog = new GuiDialogAbout ();
	testDialog->show ();
	gtkMain.run ();
}
*/

==> terraform-0.3.0.tgz: terraform-0.3.0/src/GuiDialogAbout.cc <==
/* Terraform - (C) 1997-1998 Robert Gasch (Robert_Gasch@peoplesoft.com)
 *  - www.peoplesoft.com/peoplepages/g/robert_gasch/terraform/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#include <stdio.h>
#include "terraform.h"
#include "GuiDialogAbout.h"				// include gtk, gtk--
#include "GlobalSanityCheck.h"
#include "GlobalTrace.h"
#include "MathRandom.h"



/*
 * Constructor: init everything 
 */
GuiDialogAbout::GuiDialogAbout (char *winTitle, char *filename, 
				char **msgPtrs, int nMesgs)
		: Gtk_Window (),
		  d_preview (GTK_PREVIEW_COLOR),
#ifdef HAVE_IMLIB
		  d_vBox (FALSE, 0),
		  d_frame (),
	 	  d_vBoxFrame (FALSE, 0)
#else
		  d_vBox (FALSE, 0)
#endif
{
	GlobalTrace::trace (GlobalTrace::TRACE_VERBOSE, "+++ GuiDialogAbout\n");

	SanityCheck::bailout ((!winTitle), "winTitle==NULL", "GuiAboutDialog::GuiAboutDialog");
#ifdef HAVE_IMLIB
	SanityCheck::bailout ((!filename), "filename==NULL", "GuiAboutDialog::GuiAboutDialog");
	SanityCheck::bailout ((!strlen (filename)), "strlen(filename)==0", "GuiAboutDialog::GuiAboutDialog");
#endif

	connect_to_method (button_press_event, this, &handleButtonPressEvent);

	d_winTitle = winTitle;
	d_imageFile = filename;
	d_msgPtrs = msgPtrs;
	d_nMessage = nMesgs;
	d_lblPtrs = NULL;
	this->set_events (GDK_BUTTON_PRESS_MASK | GDK_EXPOSURE_MASK);
}


/*
 * Destructor
 */
GuiDialogAbout::~GuiDialogAbout ()
{
	if (d_lblPtrs)
		{
		for (int i=0; i<d_nMessage; i++)
			delete d_lblPtrs[i];
		delete [] d_lblPtrs;
		}

	GlobalTrace::trace (GlobalTrace::TRACE_VERBOSE, "--- GuiDialogAbout\n");
}


/*
 *  (virtual) buildDialogWindow: call the proper functions to setup the window
 */
void GuiDialogAbout::buildDialogWindow ()
{
        this->set_title (d_winTitle);
	this->add (d_vBox);
        d_vBox.set_border_width (0);

#ifdef HAVE_IMLIB
	loadLogo ();
	d_vBox.pack_start (d_preview, TRUE, TRUE, 0);
	d_preview.show ();

	d_vBox.pack_start (d_frame, TRUE, TRUE, 0);
	d_frame.show ();
	d_frame.set_shadow_type (GTK_SHADOW_ETCHED_IN);
	d_frame.add (d_vBoxFrame);

	addLabels (&d_vBoxFrame);
	d_vBoxFrame.show ();

	//printf ("%d\n", d_lbl1->height());
	// how do I calculate the proper window height? 
	// d_lbl1->height() returns 1
	this->set_usize (d_image->rgb_width, d_image->rgb_height+15*d_nMessage);
#else
	addLabels (&d_vBox);
	this->set_usize (150, 75);
#endif

        d_vBox.show ();
        this->show ();
}


void GuiDialogAbout::addLabels (Gtk_VBox *vbox)
{
	char	buf[80];

	SanityCheck::bailout ((!vbox), "vbox==NULL", "GuiAboutDialog::addLabels");

	if (!d_msgPtrs)
		return;

	d_lblPtrs = new Gtk_Label*[++d_nMessage];

	sprintf (buf, "Version %d.%d.%d", 
		TF_MAJOR_VERSION, TF_MINOR_VERSION, TF_MICRO_VERSION);
	d_lblPtrs[0] = new Gtk_Label (buf);
	vbox->pack_start (*(d_lblPtrs[0]), FALSE, FALSE, 0);
	d_lblPtrs[0]->show ();

	for (int i=1; i<d_nMessage; i++)
		{
		d_lblPtrs[i] = new Gtk_Label (d_msgPtrs[i-1]);
		vbox->pack_start (*(d_lblPtrs[i]), FALSE, FALSE, 0);
		d_lblPtrs[i]->show ();
		}
}


/*
 *  (virtual) handleButtonPressEvent: catch a pressed button 
 */
gint GuiDialogAbout::handleButtonPressEvent(GdkEventButton *e)
{
	this->hide ();
	return (0);
}


/*
 *  (virtual) delete_event_impl: catch the delete event
 */
gint GuiDialogAbout::delete_event_impl (GdkEventAny *)
{
	this->hide ();
	return (0);
}


#ifdef HAVE_IMLIB

/*
 *  load_logo: load the logo from file into preview (and add preview to d_vBox)
 */
int GuiDialogAbout::loadLogo ()
{
	int		w, w3, h;
	guchar 		*pixelrow = NULL;
	MathRandom	*mRand = new MathRandom();

	gdk_imlib_init ();
	d_image = gdk_imlib_load_image (d_imageFile);
	w = d_image->rgb_width;
	h = d_image->rgb_height;

	d_preview.size (w, h);

	w3 = w*3;
	pixelrow = new guchar[w3];
	for (int i=0; i<h; i++)
		{
		memcpy (pixelrow, d_image->rgb_data+w3*i, w3);
		d_preview.draw_row (pixelrow, 0, i, w);
		}

	delete mRand;
	delete [] pixelrow;
	return (0);
}

#endif // HAVE_IMLIB

/*
int GlobalTrace::s_traceLevel = 255;
int main (int argc, char *argv[])
{
	Gtk_Main        gtkMain (&argc, &argv);
	GuiDialogAbout *testDialog;

	testDialog = new GuiDialogAbout ();
	testDialog->show ();
	gtkMain.run ();
}
*/
